# Oracle deployment abci

## Description

This module contains the ABCI oracle deployment skill for an AEA.

## Behaviours

* `DeployOracleBehaviour`

   Deploy oracle.

* `OracleDeploymentBaseState`

   Base state behaviour for the common apps' skill.

* `RandomnessOracleBehaviour`

   Retrieve randomness for oracle deployment.

* `SelectKeeperOracleBehaviour`

   Select the keeper agent.

* `ValidateOracleBehaviour`

   Validate oracle.


## Handlers

No Handlers (the skill is purely behavioural).

